@@ -158,7 +158,8 @@ where
             (elf::EM_AVR, _) => Architecture::Avr,
             (elf::EM_BPF, _) => Architecture::Bpf,
             (elf::EM_386, _) => Architecture::I386,
-            (elf::EM_X86_64, _) => Architecture::X86_64,
+            (elf::EM_X86_64, false) => Architecture::X86_64_X32,
+            (elf::EM_X86_64, true) => Architecture::X86_64,
             (elf::EM_HEXAGON, _) => Architecture::Hexagon,
             (elf::EM_MIPS, false) => Architecture::Mips,
             (elf::EM_MIPS, true) => Architecture::Mips64,
